@@ -199,13 +199,31 @@ def crossmap_gvcf_file(mapping, infile, outfile, liftoverfile, refgenome, noComp
 					fields[1] = target_start + 1
 
 					# update ref allele
+					target_chr = update_chromID(refFasta.references[0], target_chr)
 					try:
-						target_chr = update_chromID(refFasta.references[0], target_chr)
 						fields[3] = refFasta.fetch(target_chr,target_start,target_end).upper()
 					except:
 						print(line+ "\tFail(No_targetRef)", file=UNMAP)
 						failed_var += 1
 
+
+					# for insertions and deletions in a VCF file,  the first nucleotide in REF and ALT 
+					# fields correspond to the nucleotide at POS in the *reference genome*
+					ref_allele = fields[3]
+					alt_alleles = fields[4].split(',')
+					alt_alleles_updated = []
+					for alt_allele in alt_alleles:
+						if len(ref_allele) != len(alt_allele):
+							tmp = ref_allele[0] + alt_allele[1:] #replace the 1st nucleotide of ALT
+							alt_alleles_updated.append(tmp)
+						else:
+							alt_alleles_updated.append(alt_allele)
+					fields[4] = ','.join(alt_alleles_updated)
+
+					# update END if any
+					fields[7] = re.sub('END\=\d+','END='+str(target_end),fields[7])
+
+
 					if a[1][3] == '-':
 						fields[4] = revcomp_DNA(alt_allele, True) + ',<NON_REF>'
 
